@@ -427,11 +427,15 @@ class DescribeCloudRunServerDetailResponse(AbstractModel):
         :param ServerConfig: 服务配置信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type ServerConfig: :class:`tencentcloud.tcbr.v20220217.models.ServerBaseConfig`
+        :param OnlineVersionInfos: 在线版本信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OnlineVersionInfos: list of OnlineVersionInfo
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.BaseInfo = None
         self.ServerConfig = None
+        self.OnlineVersionInfos = None
         self.RequestId = None
 
 
@@ -442,6 +446,12 @@ class DescribeCloudRunServerDetailResponse(AbstractModel):
         if params.get("ServerConfig") is not None:
             self.ServerConfig = ServerBaseConfig()
             self.ServerConfig._deserialize(params.get("ServerConfig"))
+        if params.get("OnlineVersionInfos") is not None:
+            self.OnlineVersionInfos = []
+            for item in params.get("OnlineVersionInfos"):
+                obj = OnlineVersionInfo()
+                obj._deserialize(item)
+                self.OnlineVersionInfos.append(obj)
         self.RequestId = params.get("RequestId")
 
 
@@ -454,12 +464,22 @@ class DescribeCloudRunServersRequest(AbstractModel):
         r"""
         :param EnvId: 环境Id
         :type EnvId: str
+        :param PageSize: 默认为9， 最大为30
+不传或传0时 取默认9
+大于30时取30
+        :type PageSize: int
+        :param PageNum: 不传或传0时 会默认为1
+        :type PageNum: int
         """
         self.EnvId = None
+        self.PageSize = None
+        self.PageNum = None
 
 
     def _deserialize(self, params):
         self.EnvId = params.get("EnvId")
+        self.PageSize = params.get("PageSize")
+        self.PageNum = params.get("PageNum")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -478,10 +498,13 @@ class DescribeCloudRunServersResponse(AbstractModel):
         r"""
         :param ServerList: 服务列表
         :type ServerList: list of ServerBaseInfo
+        :param Total: 服务总数
+        :type Total: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.ServerList = None
+        self.Total = None
         self.RequestId = None
 
 
@@ -492,6 +515,7 @@ class DescribeCloudRunServersResponse(AbstractModel):
                 obj = ServerBaseInfo()
                 obj._deserialize(item)
                 self.ServerList.append(obj)
+        self.Total = params.get("Total")
         self.RequestId = params.get("RequestId")
 
 
@@ -542,6 +566,69 @@ class DescribeEnvBaseInfoResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeServerManageTaskRequest(AbstractModel):
+    """DescribeServerManageTask请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EnvId: 环境Id
+        :type EnvId: str
+        :param ServerName: 服务名
+        :type ServerName: str
+        :param TaskId: 任务Id
+        :type TaskId: int
+        :param OperatorRemark: 操作标识
+        :type OperatorRemark: str
+        """
+        self.EnvId = None
+        self.ServerName = None
+        self.TaskId = None
+        self.OperatorRemark = None
+
+
+    def _deserialize(self, params):
+        self.EnvId = params.get("EnvId")
+        self.ServerName = params.get("ServerName")
+        self.TaskId = params.get("TaskId")
+        self.OperatorRemark = params.get("OperatorRemark")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeServerManageTaskResponse(AbstractModel):
+    """DescribeServerManageTask返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param IsExist: 是否存在
+        :type IsExist: bool
+        :param Task: 任务信息
+        :type Task: :class:`tencentcloud.tcbr.v20220217.models.ServerManageTaskInfo`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.IsExist = None
+        self.Task = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.IsExist = params.get("IsExist")
+        if params.get("Task") is not None:
+            self.Task = ServerManageTaskInfo()
+            self.Task._deserialize(params.get("Task"))
+        self.RequestId = params.get("RequestId")
+
+
 class EnvBaseInfo(AbstractModel):
     """环境基础信息
 
@@ -876,6 +963,41 @@ class ObjectKV(AbstractModel):
         
 
 
+class OnlineVersionInfo(AbstractModel):
+    """在线版本信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param VersionName: 版本名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type VersionName: str
+        :param ImageUrl: 镜像url
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ImageUrl: str
+        :param FlowRatio: 流量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowRatio: str
+        """
+        self.VersionName = None
+        self.ImageUrl = None
+        self.FlowRatio = None
+
+
+    def _deserialize(self, params):
+        self.VersionName = params.get("VersionName")
+        self.ImageUrl = params.get("ImageUrl")
+        self.FlowRatio = params.get("FlowRatio")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class OperateServerManageRequest(AbstractModel):
     """OperateServerManage请求参数结构体
 
@@ -1014,7 +1136,7 @@ class RepositoryInfo(AbstractModel):
         :type Source: str
         :param Repo: 仓库名
         :type Repo: str
-        :param Branch: 分之名
+        :param Branch: 分支名
         :type Branch: str
         """
         self.Source = None
@@ -1180,6 +1302,95 @@ class ServerBaseInfo(AbstractModel):
         
 
 
+class ServerManageTaskInfo(AbstractModel):
+    """服务管理任务信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Id: 任务Id
+        :type Id: int
+        :param EnvId: 环境Id
+        :type EnvId: str
+        :param ServerName: 服务名
+        :type ServerName: str
+        :param CreateTime: 创建时间
+        :type CreateTime: str
+        :param ChangeType: 变更类型
+        :type ChangeType: str
+        :param ReleaseType: 发布类型
+        :type ReleaseType: str
+        :param DeployType: 部署类型
+        :type DeployType: str
+        :param PreVersionName: 上一个版本名
+        :type PreVersionName: str
+        :param VersionName: 版本名
+        :type VersionName: str
+        :param PipelineId: 流水线Id
+        :type PipelineId: int
+        :param PipelineTaskId: 流水线任务Id
+        :type PipelineTaskId: int
+        :param ReleaseId: 发布单Id
+        :type ReleaseId: int
+        :param Status: 状态
+        :type Status: str
+        :param Steps: 步骤信息
+        :type Steps: list of TaskStepInfo
+        :param FailReason: 失败原因
+        :type FailReason: str
+        :param OperatorRemark: 操作标识
+        :type OperatorRemark: str
+        """
+        self.Id = None
+        self.EnvId = None
+        self.ServerName = None
+        self.CreateTime = None
+        self.ChangeType = None
+        self.ReleaseType = None
+        self.DeployType = None
+        self.PreVersionName = None
+        self.VersionName = None
+        self.PipelineId = None
+        self.PipelineTaskId = None
+        self.ReleaseId = None
+        self.Status = None
+        self.Steps = None
+        self.FailReason = None
+        self.OperatorRemark = None
+
+
+    def _deserialize(self, params):
+        self.Id = params.get("Id")
+        self.EnvId = params.get("EnvId")
+        self.ServerName = params.get("ServerName")
+        self.CreateTime = params.get("CreateTime")
+        self.ChangeType = params.get("ChangeType")
+        self.ReleaseType = params.get("ReleaseType")
+        self.DeployType = params.get("DeployType")
+        self.PreVersionName = params.get("PreVersionName")
+        self.VersionName = params.get("VersionName")
+        self.PipelineId = params.get("PipelineId")
+        self.PipelineTaskId = params.get("PipelineTaskId")
+        self.ReleaseId = params.get("ReleaseId")
+        self.Status = params.get("Status")
+        if params.get("Steps") is not None:
+            self.Steps = []
+            for item in params.get("Steps"):
+                obj = TaskStepInfo()
+                obj._deserialize(item)
+                self.Steps.append(obj)
+        self.FailReason = params.get("FailReason")
+        self.OperatorRemark = params.get("OperatorRemark")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class StaticStorageInfo(AbstractModel):
     """静态CDN资源信息
 
@@ -1285,6 +1496,53 @@ class Tag(AbstractModel):
         
 
 
+class TaskStepInfo(AbstractModel):
+    """任务步骤信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Name: 步骤名
+        :type Name: str
+        :param Status: 未启动："todo"
+运行中："running"
+失败："failed"
+成功结束："finished"
+        :type Status: str
+        :param StartTime: 开始时间
+        :type StartTime: str
+        :param EndTime: 结束时间
+        :type EndTime: str
+        :param CostTime: 消耗时间：秒
+        :type CostTime: int
+        :param FailReason: 失败原因
+        :type FailReason: str
+        """
+        self.Name = None
+        self.Status = None
+        self.StartTime = None
+        self.EndTime = None
+        self.CostTime = None
+        self.FailReason = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Status = params.get("Status")
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.CostTime = params.get("CostTime")
+        self.FailReason = params.get("FailReason")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class UpdateCloudRunServerRequest(AbstractModel):
     """UpdateCloudRunServer请求参数结构体
 
